@@ -5,6 +5,7 @@ from .delitem import DelItemMixin
 from .embed import EmbedMixin
 from .empty import EmptyMixin
 from .evaluation import EvaluationMixin
+from .find import FindMixin
 from .getattr import GetAttributeMixin
 from .getitem import GetItemMixin
 from .group import GroupMixin
@@ -12,14 +13,13 @@ from .io.binary import BinaryIOMixin
 from .io.common import CommonIOMixin
 from .io.csv import CsvIOMixin
 from .io.dataframe import DataframeIOMixin
-from .io.dict import DictIOMixin
 from .io.from_gen import FromGeneratorMixin
 from .io.json import JsonIOMixin
 from .io.pushpull import PushPullMixin
 from .match import MatchMixin
-from .find import FindMixin
 from .parallel import ParallelMixin
 from .plot import PlotMixin
+from .post import PostMixin
 from .pydantic import PydanticMixin
 from .reduce import ReduceMixin
 from .sample import SampleMixin
@@ -27,6 +27,7 @@ from .setitem import SetItemMixin
 from .strawberry import StrawberryMixin
 from .text import TextToolsMixin
 from .traverse import TraverseMixin
+from .dataloader import DataLoaderMixin
 
 
 class AllMixins(
@@ -42,7 +43,6 @@ class AllMixins(
     CsvIOMixin,
     JsonIOMixin,
     BinaryIOMixin,
-    DictIOMixin,
     CommonIOMixin,
     EmbedMixin,
     PushPullMixin,
@@ -52,11 +52,13 @@ class AllMixins(
     TraverseMixin,
     PlotMixin,
     SampleMixin,
+    PostMixin,
     TextToolsMixin,
     EvaluationMixin,
     ReduceMixin,
     ParallelMixin,
     DataframeIOMixin,
+    DataLoaderMixin,
     ABC,
 ):
     """All plugins that can be used in :class:`DocumentArray`."""
